<?php

namespace App\Http\Controllers\Api\Global;

use App\Http\Controllers\Api\ApiController;
use App\Models\backend\Coupon;
use App\Models\backend\Food;
use App\Models\User;
use App\Models\backend\Ledger;
use App\Models\backend\FoodCategory;
use App\Models\backend\Order;
use App\Models\FeedBack;
use App\Models\Review;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class GlobalController extends ApiController
{
    public function feedback(Request $request)
    {
        $feedBack = [

            'star' => $request->star,
            'description' => $request->description,
            'user_id' => auth()->user()->id,
            'restaurant_id' => $request->restaurant_id,
            'platform_id' => 1,
        ];
        $feedback = FeedBack::create($feedBack);

        return $this->sendResponse($feedback, 'Thank you for give feedback');
    }

    public function store_feedback(Request $request)
    {
        $feedBack = [

            'feedback_for' => $request->feedback_for,
            'feedback_title' => $request->feedback_title,
            'feedback_description' => $request->feedback_description,
            'user_id' => auth()->user()->id
        ];

        $feedback = FeedBack::create($feedBack);

        return $this->sendResponse('Thank you for give feedback');
    }

    public function coupon_list(Request $request)
    {
        $coupons = Coupon::where('coupon_status', 1)->select('coupon_id', 'coupon_title', 'coupon_code','coupon_image')->get();
        $list = [];
        if ($coupons) {
            foreach ($coupons as $coupon) {
                array_push($list, [
                    'id' => $coupon->coupon_id,
                    'title' => $coupon->coupon_title,
                    'code' => $coupon->coupon_code,
                ]);
            }
            return response()->json($coupons);
        } else {
            return response()->json($coupons);
        }
    }

    public function coupon_apply(Request $request, $coupon_code)
    {
        $coupon = Coupon::where('coupon_code', $coupon_code)
            ->where('coupon_startdate', '<=', date('Y-m-d'))
            ->where('coupon_enddate', '>=', date('Y-m-d'))
            ->where('coupon_status', 1)
            ->first();

        if (!$coupon) {
            return response()->json(['msgErr' => 'Coupon not found.']);
        }

        $order_ammount = $request->order_total;

        if ($coupon->coupon_type == 'fixed') {
            $discounted_ammount = $order_ammount - $coupon->coupon_discount;
            $discount_ammount = $coupon->coupon_discount;
        }
        if ($coupon->coupon_type == 'percentage') {
            $discounted_ammount = $coupon->coupon_discount * $request->order_total / 100;
            $discount_ammount = $discounted_ammount;
            $discounted_ammount = $order_ammount - $discounted_ammount;
        }

        $list = [];
        array_push($list, [
            'coupon_title' => $coupon->coupon_title,
            'type' => $coupon->coupon_type,
            'discount' => $coupon->coupon_discount,
            'discount_ammount' => $discount_ammount,
            'coupon_id' => $coupon->coupon_id,
            'discounted_ammount' => $discounted_ammount,
            'discounted_ammount_formatted' => number_format($discounted_ammount),
        ]);

        return response()->json($list[0]);
    }

    public function storeReview(Request $request)
    {
        $this->validate($request, [
            'type' => 'required',
            'review_star' => 'required',
            'review_remarks' => 'required',
        ]);

        // if user with same type and type_id already give review then update review
        $review = Review::where('user_id', auth()->user()->id)->where('type', $request->type)->where('type_id', $request->type_id)->first();

        if ($review) {
            Review::where('user_id', auth()->user()->id)->where('type', $request->type)->where('type_id', $request->type_id)->update([
                'review_star' => $request->review_star,
                'review_remarks' => $request->review_remarks,
            ]);

            return $this->sendResponse('Thank you for give review');
        }

        $review = [
            'user_id' => auth()->user()->id,
            'type' => $request->type,
            'type_id' => $request->type_id,
            'review_star' => $request->review_star,
            'review_remarks' => $request->review_remarks,
            'review_status' => 1,
        ];

        $review = DB::table('reviews')->insert($review);
        return $this->sendResponse('Thank you for give review');
    }
    public function changeOrderStatus(Request $request)
    {
        $order = Order::find($request->id);
        $order->update(['order_status' => $request->order_status]);
        return sendResponse($order, 'Change Order Status Successfully!');
    }

    public function getPaymentHistory(Request $request)
    {
        $user_data=User::find(auth()->user()->id);
        $orders=Ledger::select('*');
        if($user_data->user_type_id==2)
            $orders=$orders->where('restaurant_id',$user_data->restaurant_id);
        else
            $orders=$orders->where('user_id',$user_data->id);
            $ledger_record=$orders->get();
        if($ledger_record){
        return sendResponse($ledger_record, '');
        }
        return sendError('No Record Found',[]);

    }

}
