<?php

namespace App\Http\Controllers\Api;

use Exception;
use App\Models\User;
use App\Models\UserAddress;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\Api\ApiController;

class LoginController extends ApiController
{
    /**
     * User login API method
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function login(Request $request)
    {
        
        $validator = Validator::make($request->all(), [
            'email'    => 'required|email',
            'password' => 'required'
        ]);

        if ($validator->fails()) return sendError('Validation Error.', $validator->errors(), 422);

        $credentials = $request->only('email', 'password');

        if (Auth::attempt($credentials)) {
            Artisan::call('config:clear');
            Artisan::call('view:clear');
            Artisan::call('route:clear');
            Artisan::call('cache:clear');
            $user=User::find(Auth::user()->id);
            $success['name']  = $user->name;
            $success['userType']  = $user->userType->name;
            $success['email']  = $user->email;
            if($user->userType->id== 3 && $user->verified==0)
            {
                return sendError('Unauthorised', ['error' => 'Account Not Verified ! Contact Admin'], 401);
            }
            if($user->userType->id== 2)
            {
                $rest_data=$user->restuarant->first();
                // pr($user->restuarant->first());
                if($rest_data->latitude==null || $rest_data->longitude==null || $rest_data->address==null || $rest_data->phone==null)
                {
                    $success['update_message']='Please update restaurant info';
                }
            }
                $success['token'] = $user->createToken('accessToken')->accessToken;

            return sendResponse($success, 'You are successfully logged in.');
        } else {
            return sendError('Unauthorised', ['error' => 'Unauthorised'], 401);
        }
    }

    public function change_password(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'old_password' => 'required',
            'new_password' => 'required|min:3',
            'confirm_password' => 'required|same:new_password'
        ]);

        if ($validator->fails()) return sendError('Validation Error.', $validator->errors(), 422);

        $user = Auth::user();

        if (password_verify($request->old_password, $user->password)) {
            $user->password = bcrypt($request->new_password);
            $user->save();

            return sendResponse([], 'Password changed successfully.');
        } else {
            return sendError('Password unmatched', ['error' => 'Password did not matched'], 401);
        }
    }

    public function forgot_password(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email'
        ]);

        if ($validator->fails()) return sendError('Validation Error.', $validator->errors(), 422);

        $user = User::where('email', $request->email)->first();

        if ($user) {
            $token = Str::random(60);

            DB::table('password_resets')->insert([
                'email' => $request->email,
                'token' => $token,
                'created_at' => Carbon::now()
            ]);

            $data = [
                'name' => $user->name,
                'email' => $user->email,
                'token' => $token
            ];

            Mail::send('email.forgot_password', $data, function ($message) use ($data) {
                // $message->from('sulaimanbarki@gmail.com', 'Sulaiman Barki');
                $message->to($data['email'], $data['name'])->subject('Forgot Password');
            });

            return sendResponse([], 'Password reset link has been sent to your email.');
        } else {
            return sendError('Email not found', ['error' => 'Email not found'], 401);
        }
    }

    /**
     * User registration API method
     *
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse
     */
    public function register(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name'     => 'required',
            'email'    => 'required|email|unique:users',
            'password' => 'required|min:3'
        ]);

        if ($validator->fails()) return $this->withError($validator->errors());

        try {
            $user = User::create([
                'name'     => $request->name,
                'email'    => $request->email,
                'lat'    => $request->lat,
                'lng'    => $request->lng,
                'contact_number'    => $request->contact_number,
                'password' => bcrypt($request->password),
                'user_type_id' => 4
            ]);

            $userAddress = [
                // 'type' => implode(',', $request->input('type')),
                'type' => $request->type,
                'lat'      => $request->lat,
                'lang'     => $request->lang,
                'address'   => $request->address,
                'zip_code'   => $request->zip_code,
                'user_id'  => $user->id,

            ];
            $user_address = UserAddress::create($userAddress);

            $success['name']  = $user->name;
            $message          = 'Yay! A user has been successfully created.';
            $success['token'] = $user->createToken('accessToken')->accessToken;
        } catch (Exception $e) {

            // $success['token'] = [];
            // $message          = 'Oops! Unable to create a new user.';
             return sendResponse($e->getLine().' - '.$e->getMessage(),'');
        }

        return sendResponse($success, $message);
    }
     public function getUser(Request $request)
    {
       $user=User::find(Auth::user()->id);
        return sendResponse($user, '');
    }
    public function getRestInfo(Request $request)
    {
        $user=User::with('restuarant')->where('id',Auth::user()->id)->first();
       return $user;

    //    $user=User::find(Auth::user()->id);
        // return sendResponse($user, '');
    }

    public function delete_account(Request $request)
    {
        User::where('id',Auth::user()->id)->update(['email'=>Auth::user()->id.'delete@ce.com','lat'=>null,'lng'=>null,'image'=>null,'contact_number'=>null,'status'=>0]);
        return sendResponse([], 'Delete successfully');

    //    $user=User::find(Auth::user()->id);
        // return sendResponse($user, '');
    }
    public function userInfoUpdate(Request $request)
    {
        // isset($request->image_name) ? $request->image_name : null,
        //  return $request->all();
        if($request->hasFile('image')){
            $image_name = time().'.'.$request->image->getClientOriginalExtension();
              $request->image->move(public_path('/app/users/'), $image_name);
        }
        else{
            $image_name="";
        }


        $user=User::find(Auth::user()->id);
        $user->name=$request->name;
        $user->email=$request->email;
        $user->image=isset($request->image_name) ? $request->image_name : null;
        $user->contact_number=$request->contact_number;
        $user->save();
        return sendResponse($user, 'User Updated SuccessFully!');
    }
    public function userAddressList()
    {
        $user=User::find(Auth::user()->id);

        $recrod=DB::table('user_addresses')->where(['user_id'=>$user->id])->get();
        // return $recrod;
        return sendResponse($recrod,'');
    }
    public function userAddressUpdate(Request $request)
    {
        // $user=User::find();
        $userid=Auth::user()->id;
        $recrod=DB::table('user_addresses')->where(['user_id'=>$userid,'type'=>$request->type])->first();
        if($recrod)
        {
            // return "exist";
            DB::table('user_addresses')->where(['user_id'=>$userid,'type'=>$request->type])->update([
                'user_id'=>$userid,
                'address'=>$request->address,
                'zip_code'=>$request->zip_code,
                'type'=>$request->type,
                'lat'=>$request->lat,
                'lang'=>$request->lang
               ]);
        }
        else

        {
            // return "not exist";
            $address=DB::table('user_addresses')->insert([
                'user_id'=>$userid,
                'address'=>$request->address,
                'zip_code'=>$request->zip_code,
                'type'=>$request->type,
                'lat'=>$request->lat,
                'lang'=>$request->lang
               ]);
        }



       return sendResponse([], 'User Address Updated SuccessFully!');
    }

    public function fcmTokenUpdate(Request $request)
    {
        $user=User::find(Auth::user()->id);
        $user->fcm_token=$request->fcm_token;
        $user->save();
        return sendResponse([],'User fcm Updated SuccessFully!');
    }

}
