<?php

namespace App\Http\Controllers\Api\Resturant;

use App\Http\Controllers\Controller;
use App\Models\backend\Food;
use App\Models\backend\Restuarant;
use App\Models\RestaurantTiming;
use App\Models\Review;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class ResturantController extends Controller
{
    public function getRestStatus()//get resturant for online or ofline
    {
        $data['rest']=DB::table('users')
        ->join('restaurants','users.restaurant_id','=','restaurants.id')
        ->select('restaurants.*')
        ->where('users.id',auth()->user()->id)->first();
            return sendResponse($data,'');
    }

    public function status(Request $request)
    {
        if (User::where('restaurant_id',auth()->user()->restaurant_id)->exists()) {
            $status = Restuarant::findOrFail(auth()->user()->restaurant_id);
            $status->status = $request->status;
            $status->update();
            if($status)
              return sendResponse($status,'Status Updated Successfully!');
        }
        else
        {
            return sendResponse([],'Record not found!');
        }
    }




    public function get_restaurant($restaurant_id)
    {
        $restaurant = Restuarant::find($restaurant_id);

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        // rating = Review
        $rating = Review::where('type', 1)->where('type_id', $restaurant_id)->avg('review_star');

        $list = [];
        array_push($list, [
            'id' => $restaurant->id,
            'name' => $restaurant->name,
            'address' => $restaurant->address,
            'closeing_time' => $restaurant->closeing_time,
            'opening_time' => $restaurant->opening_time,
            'feature_image' => $restaurant->feature_image,
            'logo' => $restaurant->logo,
            // 'cover_photo' => env('APP_URL') . '/' . $restaurant->cover_photo,
            'rating' => number_format($rating, 1)
        ]);
        return response()->json($list[0]);
    }

    // getSuggestedItems
    public function getSuggestedItems($restaurant_id)
    {
        $restaurant = Restuarant::find($restaurant_id);

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        $list = [];

        $foods = Food::where('restaurant_id', $restaurant_id)->where('is_suggested', 1)->get();
        foreach ($foods as $food) {
            array_push($list, [
                'id' => $food->id,
                'name' => $food->name,
                'price' => $food->price,
                'description' => $food->description,
                'image' => env('APP_URL') . '/app/food/' . $food->image,
                'is_veg' => $food->is_veg,
                'is_available' => $food->is_available,
                'restaurant_id' => $food->restaurant_id,
                'food_category_id' => $food->food_category_id,
            ]);
        }
        return response()->json($list);
    }

    // getRestaurantTimings
    public function getRestaurantTimings()
    {
        $id = auth()->user()->restaurant_id;
        $restaurant = Restuarant::find($id);

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        $restaurant_timings = RestaurantTiming::where('restaurant_id', $id)->get();
        $list = [];

        foreach ($restaurant_timings as $restaurant_timing) {
            $list[] = [
                'id' => $restaurant_timing->id,
                'day' => $restaurant_timing->day,
                'opening_time' => date('h:i A', strtotime($restaurant_timing->opening_time)),
                'closing_time' => date('h:i A', strtotime($restaurant_timing->closing_time)),
                'restaurant_id' => $restaurant_timing->restaurant_id,
            ];
        }
        return response()->json($list);
    }

    // changeRestaurantTimings
    public function changeRestaurantTimings(Request $request, $id)
    {
        $restaurant_timing = RestaurantTiming::find($id);

        if (!$restaurant_timing) {
            return sendResponse('Restaurant timing not found', 404);
        }

        $restaurant_timing->update([
            'opening_time' => date('H:i:s', strtotime($request->opening_time)),
            'closing_time' => date('H:i:s', strtotime($request->closing_time)),
        ]);

        return sendResponse('Restaurant timing updated successfully', 200);
    }

    // addRestaurantHoliday
    public function addRestaurantHoliday(Request $request)
    {
        $id = auth()->user()->restaurant_id;
        $restaurant = Restuarant::find($id);

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        // return $request->all();

        $holiday_date = date('Y-m-d', strtotime($request->holiday_date));

        $check_holiday = $restaurant->holidays()->where('holiday_date', $holiday_date)->first();

        if ($check_holiday) {
            $restaurant->holidays()->where('holiday_date', $holiday_date)->update([
                'reason' => $request->reason,
            ]);

            return response()->json([
                'message' => 'Holiday updated successfully'
            ]);
        }

        $restaurant->holidays()->create([
            'holiday_date' => $holiday_date,
            'reason' => $request->reason,
        ]);

        return response()->json([
            'message' => 'Holiday added successfully'
        ]);
    }

    public function update_restaurant_info(Request $request)
    {
        $id = auth()->user()->restaurant_id;
        $restaurant = Restuarant::find($id);

        if($restaurant)
        {
            if($request->latitude)
            $restaurant->latitude=$request->latitude;

            if($request->longitude)
            $restaurant->longitude=$request->longitude;

            if($request->address)
            $restaurant->address=$request->address;

            if($request->phone)
            $restaurant->phone=$request->phone;
            $restaurant->save();
            return sendResponse($restaurant, 'record update successfully');
        }
        else
        {
            return sendError('Restaurant Not Found', [], 500);
        }

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        // return $request->all();

        $holiday_date = date('Y-m-d', strtotime($request->holiday_date));

        $check_holiday = $restaurant->holidays()->where('holiday_date', $holiday_date)->first();

        if ($check_holiday) {
            $restaurant->holidays()->where('holiday_date', $holiday_date)->update([
                'reason' => $request->reason,
            ]);

            return response()->json([
                'message' => 'Holiday updated successfully'
            ]);
        }

        $restaurant->holidays()->create([
            'holiday_date' => $holiday_date,
            'reason' => $request->reason,
        ]);

        return response()->json([
            'message' => 'Holiday added successfully'
        ]);
    }

    // getRestaurantHoliday
    public function getRestaurantHoliday()
    {
        $id = auth()->user()->restaurant_id;
        $restaurant = Restuarant::find($id);

        if (!$restaurant) {
            return response()->json([
                'message' => 'Restaurant not found'
            ], 404);
        }

        $list = [];

        $holidays = $restaurant->holidays()->orderBy('holiday_date', 'desc')->get();
        foreach ($holidays as $holiday) {
            $list[] = [
                'id' => $holiday->id,
                'holiday_date' => $holiday->holiday_date,
                'reason' => $holiday->reason,
            ];
        }
        return response()->json($list);
    }

    // getRestaurantRating
    public function getRating()
    {

         $rating = Review::where('user_id',auth()->user()->id)->get();
         if ($rating)
         return sendResponse($rating,'');
         return sendError($rating,'not found!');


    }


}
