<?php

namespace App\Http\Controllers\backend;

use Illuminate\Http\Request;
use App\Models\backend\Coupon;
use App\Http\Controllers\Controller;

class CouponsController extends Controller
{
    public function index()
    {
        $coupons = Coupon::all();
        return view('backend.pages.coupons.index', compact('coupons'));
    }

    public function create()
    {
        return view('backend.pages.coupons.create');
    }
    public function store(Request $request)
    {
        // dd($request->all());
        $request->validate([
            'coupon_title' => 'required',
            'coupon_type' => 'required',
            'coupon_value' => 'required',
            'coupon_code' => 'required|unique:coupons,coupon_code',
            'coupon_discount' => $request->type === 'percent' ? 'numeric|required|min:0|max:100' : 'required|numeric',
            'coupon_startdate' => 'required',
            'coupon_enddate'  => 'required',
            'coupon_quantity' => 'required',
            'coupon_percoustomer' => 'required',
            'coupon_maximum_spend' => 'required|gt:coupon_minimum_spend',
            'coupon_minimum_spend' => 'required|lt:coupon_maximum_spend',
            'coupon_image' => 'image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ], [
            'coupon_discount.min' => 'The discount must be at least 0.',
            'coupon_discount.max' => 'The discount may not be greater than 100.',
        ]);

        if ($request->hasFile('coupon_image')) {
            $coupon_image = time() . rand(200, 400) . '.' . $request->coupon_image->getClientOriginalExtension();
            $request->coupon_image->move(public_path('/app/coupon/'), $coupon_image);
        } else {
            $coupon_image = '';
        }

        $coupon = Coupon::create([
            'coupon_code'  => $request->coupon_code,
            'coupon_title'  => $request->coupon_title,
            'coupon_type'  => $request->coupon_type,
            'coupon_value'  => $request->coupon_value,
            'coupon_discount'  =>   $request->coupon_discount,
            'coupon_startdate'  => date('Y-m-d', strtotime($request->coupon_startdate)),
            'coupon_enddate' => date('Y-m-d', strtotime($request->coupon_enddate)),
            'coupon_quantity'  => $request->coupon_quantity,
            'coupon_percoustomer'  => $request->coupon_percoustomer,
            'coupon_maximum_spend' => $request->coupon_maximum_spend,
            'coupon_minimum_spend' => $request->coupon_minimum_spend,
            'coupon_image' => $coupon_image,
        ]);

        // if ($request->payment_card) {
        //     foreach ((array) $request->payment_card as $row) {
        //         McouponToPaymentCard::create([
        //             'coupon_id' => $coupon->coupon_id,
        //             'card_name' => $row
        //         ]);
        //     }
        // }

        // $coupon_data = [
        //     'coupon_id' => $coupon->coupon_id,
        //     'coupon_title' => $coupon->coupon_title . ' is a new active coupon, visit the shop to see it',
        //     'coupon_code' => $coupon->coupon_code,
        //     'coupon_discount' => $coupon->coupon_discount,
        //     'coupon_enddate' => $coupon->coupon_enddate
        // ];

        // $customers = DB::table('wq_users')
        //     ->join('user_to_type', 'wq_users.user_id', 'user_to_type.user_id')
        //     ->join('wq_usertype', 'user_to_type.usertype_id', 'wq_usertype.usertype_id')
        //     ->where('wq_usertype.usertype_slug', 'customer')
        //     ->pluck('wq_users.user_id');


        // foreach ($customers as $customer) {
        //     $user = User::find($customer);
        //     Notification::send($user, new CouponNotification($coupon_data));
        // }

        return redirect()->route('coupons.index')->with('success', 'Coupon created successfully');

    }
    public function edit($id){
        $All_zones = Coupon::where('coupon_id',$id)->first();
        return view('backend.pages.coupons.edit',compact('All_zones'));
    }
    public function update(Request $request, $id)
    {
        $request->validate([
            'coupon_title' => 'required',
            'coupon_type' => 'required',
            'coupon_value' => 'required',
            // 'coupon_code' => 'required|unique:coupons,coupon_code',
            'coupon_discount' => $request->type === 'percent' ? 'numeric|required|min:0|max:100' : 'required|numeric',
            'coupon_startdate' => 'required',
            'coupon_enddate'  => 'required',
            'coupon_quantity' => 'required',
            'coupon_percoustomer' => 'required',
            'coupon_maximum_spend' => 'required|gt:coupon_minimum_spend',
            'coupon_minimum_spend' => 'required|lt:coupon_maximum_spend',
            // 'coupon_image' => 'image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ], [
            'coupon_discount.min' => 'The discount must be at least 0.',
            'coupon_discount.max' => 'The discount may not be greater than 100.',
        ]);
        //    $coupon = Coupon::where('coupon_id',$id)->first();
        if ($request->hasFile('coupon_image')) {
            $coupon_image = time() . rand(200, 400) . '.' . $request->coupon_image->getClientOriginalExtension();
            $request->coupon_image->move(public_path('/app/coupon/'), $coupon_image);
        } else {
            $coupon_image = '';
        }
        $search_coupon = Coupon::where('coupon_id','!=',$id)->where('coupon_code',$request->coupon_code)->first();
        if($search_coupon)
        {
            $request->validate(['coupon_code' => 'required|unique:coupons,coupon_code']);
        }

       $coupon = Coupon::where('coupon_id',$id)->update([
        'coupon_code'  => $request->coupon_code,
        'coupon_title'  => $request->coupon_title,
        'coupon_type'  => $request->coupon_type,
        'coupon_value'  => $request->coupon_value,
        'coupon_discount'  =>   $request->coupon_discount,
        'coupon_startdate'  => date('Y-m-d', strtotime($request->coupon_startdate)),
        'coupon_enddate' => date('Y-m-d', strtotime($request->coupon_enddate)),
        'coupon_quantity'  => $request->coupon_quantity,
        'coupon_percoustomer'  => $request->coupon_percoustomer,
        'coupon_maximum_spend' => $request->coupon_maximum_spend,
        'coupon_minimum_spend' => $request->coupon_minimum_spend,
        'coupon_image' => $coupon_image,
        ]);
        // $zone_update->update();
        //    ]);
        return redirect()->route('coupons.index')->with('success','Zone updated successfully');

    }
    public function delete($id)
    {
        $delete = Coupon::find($id)->delete();
        return redirect()->route('coupons.index')->with('success','Zone Deleted Successfully');
    }
}
