<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserType;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Hash;


use Illuminate\Support\Facades\Validator;

class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $users = User::where('user_type_id', 4)->get();
        return view('backend.pages.users.index', compact('users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $usersType = UserType::get();

        return view('backend.pages.users.create', compact('usersType'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {


        $validator = Validator::make($request->all(), [
            'name' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = $validator->errors();
            foreach ($errors->messages() as $key => $error) {
                return redirect()->route('customers.index')->with('error', 'fill all fields');
            }
            return redirect()->back();
        }

        $data = $request->all();
        $data['password'] = Hash::make($data['password']);
        $data['user_type_id']=4;
        // dd($data);
        unset($data['_token']);
        $user = User::Create($data);
        if ($user) {
            return redirect()->route('customers.index')->with('success', 'User Created Successfully');
        } else {
            return redirect()->route('customers.index')->with('error', 'Fail to crate new user');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::where('id', $id)->first();
        return view('backend.pages.users.show', compact('user'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::where('id', $id)->first();
        // $usersType = UserType::get();

        return view('backend.pages.users.edit', compact('user'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $validator = Validator::make($request->all(), [
            'name' => 'required',
        ]);

        if ($validator->fails()) {
            $errors = $validator->errors();
            foreach ($errors->messages() as $key => $error) {
                return redirect()->route('customers.index')->with('error', 'fill all fields');
            }
            return redirect()->back();
        }

        $user = User::find($id);
        $data = $request->all();
        if (!empty($data['password'])) {
            $data['password'] = Hash::make($data['password']);
        }
        if ($user) {
            $user->fill($data);
            $user->save();
            return redirect()->route('customers.index')->with('success', 'User Created Successfully');
        } elseif (!$user) {
            return redirect()->route('customers.index')->with('error', 'User in not exist in the database');
        } else {
            return redirect()->route('customers.index')->with('error', 'Fail to crate new user');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $delete = User::find($id);
        $delete->delete();
        return redirect()->route('customers.index')->with('success', 'User Deleted Successfully');
    }
}
