<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\backend\DeliveryMan;
use App\Models\backend\Order;
use App\Models\backend\Zone;
use App\Models\backend\OrderRequestToDeliveryMan;
use App\Models\backend\DeliveryManDetails;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use League\CommonMark\Delimiter\Delimiter;

class DeliveryManController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['deliverymanDetail'] = User::where('user_type_id',3)->orderBy('id','DESC')->get();
        //  dd($data['deliverymanDetail']);
        return view('backend.pages.deliveryman.index', $data);
    }

    public function unVerifiedList()
    {
        $data['deliverymanDetail'] = User::where('user_type_id',3)->where('verified',0)->orderBy('id','DESC')->get();
        //  dd($data['deliverymanDetail']);
        return view('backend.pages.deliveryman.index', $data);
    }

    public function disabledList()
    {
        $data['deliverymanDetail'] = User::where('user_type_id',3)->where('status',0)->orderBy('id','DESC')->get();
        //  dd($data['deliverymanDetail']);
        return view('backend.pages.deliveryman.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $zones=Zone::all();
        return view('backend.pages.deliveryman.create',compact('zones'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'name' => 'required',
            'password' => 'required|confirmed|min:5',
            'email' => 'required|email|unique:users',
            'zone_id' => 'required|integer',
            'status' => 'required|integer',
            'verified' => 'required',
            // 'identity_number' => 'required',
            'contact_number' => 'required',
            // 'type' => 'required',
        ]);

        // dd($request->all());
        DB::beginTransaction();
        try {
            // $this->validateDeliverMan($request);
            $passwords = $request->password;
            $user_data = [
                'name' => $request->name,
                'contact_number' => $request->contact_number,
                'user_type_id'=> 3,
                // 'user_type_id'=> $request->type,
                'status'=>$request->status,
                'verified'=>$request->verified,
                'email' => $request->email,
                'password' => Hash::make($passwords)
            ];
            $user = User::create($user_data);
            $deliveryDetail = [
                // 'restaurant_id'=>1,
                'identity_number' => $request->identity_number,
                'identity_type' => $request->identity_type,
                'zone_id' => $request->zone_id,
                'type' => $request->type,
                'user_id' => $user->id
                // 'country_id' => $request->country_id,
                // 'city_id' => $request->city_id,

            ];
            DB::table('delivery_men_details')->insert($deliveryDetail);
            DB::commit();
            return redirect()->route('deliverymans.index')->with('success', 'Added Successfully!');
         } catch ( \Exception $e ) {
                DB::rollBack();
                // dd($e->getLine() . ' - ' . $e->getMessage());
                return redirect()->back()->with( 'error', $e->getLine() . ' - ' . $e->getMessage() );
              }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // dD($id);
        $zone=[];
        $user=User::find($id);
        $dmdetails=DeliveryManDetails::where('user_id',$id)->first();
        if($dmdetails && $dmdetails->count())
        $zone=Zone::where('id',$dmdetails->zone_id)->first();
        // dd($dmdetails);

        $doc=DeliveryMan::where('driver_user_id',$id)->get();
         return view('backend.pages.deliveryman.show',compact('user','dmdetails','zone','doc'));
    }


    public function findDeliveryMans(Request $r)
    {
        $kilometer=$r->kilometer;
        $r=Order::with('restaurant')->find($r->orderId);

        $lat=$r->restaurant->latitude;
        $lon=$r->restaurant->longitude;

            $riders = DB::table("delivery_man_current_location")
                ->select(
                    "delivery_man_current_location.user_id",
                    "users.name",
                    DB::raw("6371 * acos(cos(radians(" . $lat . "))
                    * cos(radians(delivery_man_current_location.lat))
                    * cos(radians(delivery_man_current_location.lang) - radians(" . $lon . "))
                    + sin(radians(" . $lat . "))
                    * sin(radians(delivery_man_current_location.lat))) AS distance")
                )
                ->groupBy("delivery_man_current_location.location_id")
                ->join('users', 'users.id', '=', 'delivery_man_current_location.user_id')
                // ->rightJoin('order_request_to_delivery_man', 'order_request_to_delivery_man.user_id', '=', 'delivery_man_current_location.user_id')
                ->having('distance','<=', $kilometer)
                ->where('users.user_type_id',3)
                ->where('users.user_online',1)
                ->where('users.verified',1)
                ->where('users.rider_busy',0)
                // ->where('order_request_to_delivery_man.status','!=','pending')
                ->get();
            
                // if($rider)


            // if ($riders) {

            //     foreach ($riders as $k => $r) {
            //         $data[] = array(
            //             'user_id' => $r->user_id,
            //             'order_id' => $orderCreate->id,
            //         );
            //     }
            //     DB::table('order_request_to_delivery_man')->insert($data);
            // }

        return  sendResponse($riders,'');
    }

    public function assignRiderToOrder($order_id,Request $r)
    {
        $this->validate( $r, [
            'rider_id' => ['required'],
        ]);

                    $data = array(
                        'user_id' => $r->rider_id,
                        'order_id' => $order_id,
                    );
                    OrderRequestToDeliveryMan::updateOrCreate($data);
                    DB::table('users')->where('id',$r->rider_id)->update(['rider_busy'=>1]);
                    $user=DB::table('users')->where('id',$r->rider_id)->first();

                    sendNotification($user->fcm_token, 'Order #'.$order_id, 'New Order Assigned');

        // return  redirect()->withSuccess('Rider Assign Successfully');
        return redirect()->route('get_all_order_not_assigned_to_driver')->withSuccess('Rider Assign Successfully');
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $zones=Zone::where('status',1)->get();
        $user=User::find($id);
        $ddata=DeliveryManDetails::where('user_id',$id)->first();
        // dd($ddata);
        return view('backend.pages.deliveryman.edit',compact('zones','user','ddata'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
            $validated_rule=[
            'name' => 'required',
            // 'password' => 'required|confirmed|min:5',
            // 'email' => 'required|email|unique:users',
            'zone_id' => 'required|integer',
            // 'identity_type' => 'required',
            'status' => 'required|integer',
            'verified' => 'required|integer',

            'contact_number' => 'required',
            // 'type' => 'required',
            ];
           
        if($request->password)
            $validated_rule['password']='required|confirmed|min:5';
        if($request->email)
            $validated_rule['email']='required|email|unique:users';
        
         $validatedData = $request->validate($validated_rule);    

        // dd($request->all());
        DB::beginTransaction();
        try {
            // $this->validateDeliverMan($request);
            // $passwords = $request->password;
            $user_data = [
                'name' => $request->name,
                'contact_number' => $request->contact_number,
                // 'user_type_id'=> 3,
                 'status'=>$request->status,
                 'verified'=>$request->verified,
                // 'user_type_id'=> $request->type,
                // 'restaurant_id'=>1,
                // 'email' => $request->email,
                // 'password' => Hash::make($passwords)
            ];
            if($request->password)
                $user_data['password'] = Hash::make($request->password);

            if($request->email)
                $user_data['email'] = $request->email;

            $user = User::where('id', $id)->update($user_data);
            $deliveryDetail = [
                // 'restaurant_id'=>1,
                'identity_number' => $request->identity_number,
                'identity_type' => $request->identity_type,
                'zone_id' => $request->zone_id,
                'type' => $request->type,
                // 'user_id' => $id
                // 'country_id' => $request->country_id,
                // 'city_id' => $request->city_id,

            ];
            DB::table('delivery_men_details')->where('id',$request->delivery_men_details_id)->update($deliveryDetail);
            DB::commit();
            return redirect()->route('deliverymans.index')->with('success', 'Update  Successfully!');
         } catch ( \Exception $e ) {
                DB::rollBack();
                // dd($e->getLine() . ' - ' . $e->getMessage());
                return redirect()->back()->with( 'error', $e->getLine() . ' - ' . $e->getMessage() );
              }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // dd($id);
        $user = User::find($id);
        // $fdelete = DeliveryMan::where('user_id',$user->id)->delete();
        $user->status=0;
        $user->save();
        return redirect()->route('deliverymans.index')->with('success',"Deleted Successfully!");
    }

    public function validateDeliverMan(Request $request)
    {
        $this->validate($request, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:3', 'confirmed'],
        ]);
    }
}
