<?php

namespace App\Http\Controllers\backend;;

use App\Models\backend\Food;
use App\Http\Controllers\Controller;
use App\Models\backend\FoodCategory;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class FoodController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        // $data['foods'] = Food::all();
        $data['foods'] = Food::where('restaurant_id',auth()->user()->restaurant_id)->orderBy('id', 'DESC')->get();
        return view('backend.restaurant-panel.foods.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $data['categories'] = FoodCategory::all();
        return view('backend.restaurant-panel.foods.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {


        $this->validate($request, [
            'name' => 'required',
            'category_id' => 'required',
            'price' => 'required|numeric',
            'image' => ['required'],
            'image.*' => ['mimes:jpeg,jpg,png,gif|required|max:10000'],
        ]);
        if ($request->hasFile('image')) {
            $food_image = time() . '.' . $request->image->getClientOriginalExtension();
            $request->image->move(public_path('/app/food/'), $food_image);

            // $imgName = time() . '.' . $request->image->extension();
            // $request->image->storeAs('public/foodcategory', $imgName);
            // $data['image'] = $imgName;

            // featured_image
//            if ($request->hasFile('featured_image')) {
//                $featured_image = time() . rand(200, 400) . '.' . $request->featured_image->getClientOriginalExtension();
//                $request->featured_image->move(public_path('/app/food/'), $featured_image);
//            } else {
//                $featured_image = '';
//            }


            $data = [
                'name' => $request->name,
                'category_id' => $request->category_id,
                'price' => $request->price,
                'description' => $request->description,
                'image' => $food_image,
                'is_suggested' => $request->is_suggested,
                'featured_image' => 'featured_image',
            ];
            $data['restaurant_id'] = auth()->user()->restaurant_id;
            Food::create($data);
        }
        return redirect()->route('foods.index')->with('success', 'Added Successfully!');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Food  $food
     * @return \Illuminate\Http\Response
     */
    public function show(Food $food)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Food  $food
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['food'] = Food::find($id);
        $data['categories'] = FoodCategory::all();
        return view('backend.restaurant-panel.foods.create', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Food  $food
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if (Food::where('id',$id)->exists()) {
        $this->validate($request, [
            'image' => ['required'],
            'image.*' => ['mimes:jpeg,jpg,png,gif|required|max:10000']
        ]);
        $food = Food::find($id);
        if (is_file('/app/food/' . $food->image)) {
            unlink(public_path() . '/app/food/' . $food->image);
        }
        $file_name = time() . '.' . $request->image->getClientOriginalExtension();
        $request->image->move(public_path('/app/food/'), $file_name);

        // featured_image
//        if ($request->hasFile('featured_image')) {
//            if (is_file('/app/food/' . $food->featured_image)) {
//                unlink(public_path() . '/app/food/' . $food->featured_image);
//            }
//            $featured_image = time() . rand(1, 200) . '.' . $request->featured_image->getClientOriginalExtension();
//            $request->featured_image->move(public_path('/app/food/'), $featured_image);
//        } else {
//            $featured_image = $food->featured_image;
//        }

        $food->name = $request->name;
        $food->description= $request->description;
        $food->category_id= $request->category_id;
        $food->price= $request->price;
        $food->image= $file_name;
        $food->is_suggested= $request->is_suggested;
        $food->update();
        return redirect()->route('foods.index')->with('success','Update Successfully!');
    }
    return back()->with('error','Record not found!');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Food  $food
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $delete_id = Food::find($id);
        $delete_id->delete();
        return redirect()->route('foods.index')->with('success', 'Food deleted successfully!');
    }
}
