<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\backend\Order;
use App\Models\backend\OrderStatus;
use App\Models\backend\Status;
use App\Models\Location;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\Response;

class OrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // dd(Auth::user()->restaurant_id);
        return view('backend.restaurant-panel.orders.index');
    }

    public function showOrder(Request $request)
    {
        $data['orders'] = Order::with('orderDetail')->where('order_status', 'confirmed')->where('restaurant_id',Auth::user()->restaurant_id)->get();
        return sendResponse($data,'');
    }
    public function changeStatus(Request $request)
    {
        $order = Order::find($request->id);
        $order->update(['order_status' => 'accepted']);
        return sendResponse($order, 'Order Accepted Successfully!');
    }



    public function getUserNearByDistance(Request $request)
    {

// ===============second solution==============
// this solution find the distance and also get users
        $lat = 33.9995999;
        $lon = 71.465306;
        $distance = 10; //km
        $users = User::select(
            "users.*",
            DB::raw("6371 * acos(cos(radians(" . $lat . "))
                * cos(radians(users.lat))
                * cos(radians(users.lng) - radians(" . $lon . "))
                + sin(radians(" . $lat . "))
                * sin(radians(users.lat))) AS distance")
        )
            ->groupBy("users.id")
            ->having('distance', '<=', $distance)
            ->get();

        return  $users;



        // ===============second solution==============
        // THIS solution find the max min distance
    //     $lat = 50.223137; //latitude
    //     $lon = 18.679558; //longitude
    //     $distance = 5; //your distance in KM
    //     $R = 6371; //constant earth radius. You can add precision here if you wish

    //     $maxLat = $lat + rad2deg($distance / $R);
    //     $minLat = $lat - rad2deg($distance / $R);
    //     $maxLon = $lon + rad2deg(asin($distance / $R) / cos(deg2rad($lat)));
    //     $minLon = $lon - rad2deg(asin($distance / $R) / cos(deg2rad($lat)));

    //    return $maxLat. " ". "<br>". "".$minLat." "."<br>"." ".$maxLon."". "<br>"."". $minLon;
    }

    public function getOrders(Request $request, Order $order)
    {

        $data = $order->where('restaurant_id', Auth::user()->restaurant_id)->get();
        return DataTables::of($data)
            ->addColumn('action', function (Order $order) {
                $actionBtn = '<div class="btn-group">
            <a class="action-icon statusUpdate" data-id="' . $order->id . '" data-bs-toggle="modal" data-bs-target="#statusUpdate"> <i class="mdi mdi-pencil"></i></a>
            <a href="javascript: void(0);" class="action-icon"> <i class="mdi mdi-delete"></i></a>

        </div>';
                return $actionBtn;
            })
            ->rawColumns(['action'])
            ->make(true);
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function getOrderStatus(Request $request)
    {


        $records = Order::with('statuses')->where('id', $request->id)->first();
        // $collapsed = flatten($records);

        return response()->json(array('true' => false, 'data'   =>  $records));
    }
    public function updateOrderStatus(Request $request)
    {
        // if($request->order_id!="" && $request->id!=""){
        DB::beginTransaction();
        try {
            $this->validateOrderStatus($request);

            $data = [
                "order_id" => $request->order_id,
                "status_id" => $request->id,
            ];
            $order = Order::find($request->order_id);
            $order->update(['order_status' => 'confirm']);
            // return $orderStatus;
            $createOrderStatus = OrderStatus::create($data);
            // return response()->with('success','Status successfully!');
            // return response()->json($createOrderStatus);
            DB::commit();
            return Response::json(['success', 'Added Record successfully!']);
            // return response()->json(['success', 'Data Inserted successfully']);
        } catch (\Exception $e) {
            DB::rollBack();
            return Response::json(['error' => $e->getMessage()]);
            // return response()->json(['error' => $e->getMessage()]);
            // return response()->json(['error', 'Something went wrong!']);
        }
        // }

        // else{
        //     return response()->json(['error', 'Record Not Found!']);
        // }





    }
    public function create()
    {
        //
    }

    public function get_all_order_not_assigned_to_driver()
    {
        $data['orders'] = Order::with('orderDetail.food','assignedDeliveryMan')->where('order_status','pending')->orderBy('id','DESC')->get();
        // $data['orders'] = DB::table('orders')->where('order_status','pending')->get()->pluck('id')->toArray();
        // dd($data);
        return view('backend.pages.order.not-assigned-order', $data);
    }

    public function get_all_order_assigned_to_driver()
    {
        $data['orders'] = Order::whereHas('assignedDeliveryMan')->with('orderDetail.food','assignedDeliveryMan')->where('order_status','pending')->orderBy('id','DESC')->limit(100)->get();
        // $data['orders'] = DB::table('orders')->where('order_status','pending')->get()->pluck('id')->toArray();
        // dd($data);
        return view('backend.pages.order.assigned-order', $data);
    }
    public function not_assign_order_edit($id)
    {
        $data['order'] = Order::with('restaurant','orderDetail.food','assignedDeliveryMan')->find($id);
        // dd($data);

        return view('backend.pages.order.not_assign_order_edit', $data);
    }
    public function getOrderById($id)
    {
        $data['order'] = Order::with('restaurant','orderDetail.food','assignedDeliveryMan')->find($id);
        // dd($data);

        return view('backend.pages.order.single_order_view', $data);
    }

    public function get_all_order_not_assigned_to_driver_for_ajax()
    {
        $data['orders'] = Order::with('user:id,name','orderDetail.food','assignedDeliveryMan')->where('order_status','pending')->orderBy('id','DESC')->get();
        // $data['orders'] = DB::table('orders')->where('order_status','pending')->get()->pluck('id')->toArray();
        // dd($data);
        // return view('backend.pages.order.not-assigned-order', $data);
        return response()->json($data);
    }

    public function get_all_order_assigned_to_driver_for_ajax()
    {
        // $data['orders'] = Order::with('user:id,name','orderDetail.food','assignedDeliveryMan')->where('order_status','pending')->orderBy('id','DESC')->get();
        $data['orders'] = Order::whereHas('assignedDeliveryMan')->with('user:id,name','orderDetail.food','assignedDeliveryMan')->where('order_status','pending')->orderBy('id','DESC')->limit(100)->get();
        // $data['orders'] = DB::table('orders')->where('order_status','pending')->get()->pluck('id')->toArray();
        // dd($data);
        // return view('backend.pages.order.not-assigned-order', $data);
        return response()->json($data);
    }


    

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function show(Order $order)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function edit(Order $order)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Order $order)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Order  $order
     * @return \Illuminate\Http\Response
     */
    public function destroy(Order $order)
    {
        //
    }

    public function validateOrderStatus(Request $request)
    {
        $this->validate($request, [
            'order_id' => 'required',
            'status_id' => 'required'
            // 'email' => 'required|email'
        ]);
    }
}
