<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\backend\Receipt;
use App\Models\backend\ReceiptDetail;
use App\Models\backend\Restuarant;
use App\Models\backend\Profit;
// use App\Models\backend\Food;
use App\Models\User;
use Facade\FlareClient\Http\Response;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class ReceiptController extends Controller
{

    public function get_balance(Request $request)
    {
        if($request->type=='Restaurant')
            $data['balance'] = DB::table('ledgers')->where('restaurant_id',$request->res_id)->sum('amount');
        else
            $data['balance'] = DB::table('ledgers')->where('user_id',$request->del_id)->sum('amount');
        return response()->json($data);
    }

    public function get_balance_where(Request $request)
    {
        if($request->type=='Restaurant')
            $data['balance'] = DB::table('ledgers')->where('restaurant_id',$request->res_id)->where('id','!=',$request->id)->sum('amount');
        else
            $data['balance'] = DB::table('ledgers')->where('user_id',$request->del_id)->where('id','!=',$request->id)->sum('amount');
        return response()->json($data);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // $data['restuarants'] = Receipt::orderBy('id', 'Desc')->get();
        $data['restuarants'] = Receipt::with('bRestaurant')->orderBy('id', 'Desc')->limit(200)->get();
        // dd($data);
        return view('backend.pages.receipt.index', $data);
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $zones = Restuarant::where('status',1)->get();
        $delivery_man = User::select('id','name','email')->where('status',1)->where('verified',1)->where('user_type_id',3)->get();
        // pr($delivery_man);
        return view('backend.pages.receipt.create', compact('zones','delivery_man'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        $request->validate([
            'payment_date' => 'required',
            'Payed_for' => 'required',
            'deliveryman' => ['required_if:Payed_for,Delivery Man'],
            'restaurant' => ['required_if:Payed_for,Restaurant'],
            'payment_amount' => 'required|numeric|gt:0',
        ]);
        DB::beginTransaction();
        try {

                    $data = [
                        'receipt_date' => $request->payment_date,
                        'restaurant_id' => $request->restaurant,
                        'user_id' => $request->deliveryman,
                        'total_paid_amount' => $request->payment_amount,
                        'note' => $request->note,
                        'payment_for' => $request->Payed_for,
                    ];
                    if($request->Payed_for !='General Expense')
                        {
                        
                        // if ($request->feature_image) {
                        //     $feature_image = time() . rand(200, 400) . '.' . $request->feature_image->getClientOriginalExtension();
                        //     $request->feature_image->move(public_path('/app/restaurant/'), $feature_image);
                        // } else {
                        //     $feature_image = '';
                        // }
                        // if ($request->logo) {
                        //     $logo = time() . rand(200, 400) . '.' . $request->logo->getClientOriginalExtension();
                        //     $request->logo->move(public_path('/app/restaurant/'), $logo);
                        // } else {
                        //     $logo = '';
                        // }
                        // $data['logo'] = $logo;
                        // $data['feature_image'] = $feature_image;
                        
                        // $passwords = $request->password;
                        
                        $receipt_id = Receipt::insertGetId($data);

                        $data3 = [
                            // 'receipt_date' => $request->payment_date,
                            'payed_amount' => $request->payment_amount,
                            'receipt_id' => $receipt_id,
                        ];
                        $res_id = ReceiptDetail::insert($data3);


                        $data2 = [
                            'user_id' => $request->deliveryman,
                            'restaurant_id' => $request->restaurant,
                            'amount' => -($request->payment_amount),
                            'ledger_date' => $request->payment_date,
                            'receipt_id' => $receipt_id,
                        ];
                        DB::table('ledgers')->insert($data2);
                        }
                    else
                        {
                            $receipt_id = Receipt::insertGetId($data);
                
                            $data3 = [
                                'payed_amount' => $request->payment_amount,
                                'receipt_id' => $receipt_id,
                            ];
                              ReceiptDetail::insert($data3);

                            $data4 = [
                                'amount' => -($request->payment_amount),
                                'receipt_id' => $receipt_id,
                                'type' => 'Expense',
                            ];
                             Profit::insert($data4);


                        }

                    // $user = User::create($user_data);
                DB::commit();
                return redirect()->route('receipt.index')->with('success', 'Added Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();

            return back()->with('error', 'Data Not Inserted Please Try Again! ' . '' . $e->getLine() . ' - ' . $e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // dd('testing');
        $zones = Restuarant::where('status',1)->get();
        $delivery_man = User::select('id','name','email')->where('status',1)->where('verified',1)->where('user_type_id',3)->get();
        $record=Receipt::find($id);
        // pr($delivery_man);
        return view('backend.pages.receipt.edit', compact('zones','delivery_man','record'));

        // return view('backend.pages.receipt.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // dd($request->all());
        $request->validate([
            'payment_date' => 'required',
            'Payed_for' => 'required',
            'deliveryman' => ['required_if:Payed_for,Delivery Man'],
            'restaurant' => ['required_if:Payed_for,Restaurant'],
            'payment_amount' => 'required|numeric|gt:0',
        ]);
        DB::beginTransaction();
        try {

                    $data = [
                        'receipt_date' => $request->payment_date,
                        // 'restaurant_id' => $request->restaurant,
                        // 'user_id' => $request->deliveryman,
                        'total_paid_amount' => $request->payment_amount,
                        'note' => $request->note,
                        'payment_for' => $request->Payed_for,
                    ];
                    if($request->Payed_for =='Restaurant')
                    {

                        $data['restaurant_id']=$request->restaurant;
                        $data['user_id']=null;
                    }
                    else if($request->Payed_for =='Delivery Man')
                    {
                        $data['restaurant_id']=null;
                        $data['user_id']=$request->deliveryman;
                    }
                    else
                    {
                        $data['restaurant_id']=null;
                        $data['user_id']=null;
                    }
                    if($request->Payed_for !='General Expense')
                    {
                            
                        
                        // if ($request->feature_image) {
                        //     $feature_image = time() . rand(200, 400) . '.' . $request->feature_image->getClientOriginalExtension();
                        //     $request->feature_image->move(public_path('/app/restaurant/'), $feature_image);
                        // } else {
                        //     $feature_image = '';
                        // }
                        // if ($request->logo) {
                        //     $logo = time() . rand(200, 400) . '.' . $request->logo->getClientOriginalExtension();
                        //     $request->logo->move(public_path('/app/restaurant/'), $logo);
                        // } else {
                        //     $logo = '';
                        // }
                        // $data['logo'] = $logo;
                        // $data['feature_image'] = $feature_image;
                        
                        // $passwords = $request->password;

                        
                        $receipt_id = Receipt::where('id',$id)->update($data);

                        $data3 = [
                            // 'receipt_date' => $request->payment_date,
                            'payed_amount' => $request->payment_amount,
                            'receipt_id' => $id,
                        ];

                        $res_id = ReceiptDetail::where('receipt_id',$id)->delete();
                        $res_id = ReceiptDetail::insert($data3);


                        $data2 = [
                            'user_id' => $request->deliveryman,
                            'restaurant_id' => $request->restaurant,
                            'amount' => -($request->payment_amount),
                            'ledger_date' => $request->payment_date,
                        ];
                        DB::table('ledgers')->where('receipt_id',$id)->delete();
                        Profit::where('receipt_id',$id)->delete();

                        DB::table('ledgers')->insert($data2);


                        }
                    else
                        {
                            $receipt_id = Receipt::where('id',$id)->update($data);
                            $data3 = [
                                'payed_amount' => $request->payment_amount,
                                'receipt_id' => $id,
                            ];
                
                            $res_id = ReceiptDetail::where('receipt_id',$id)->delete();
                            $res_id = ReceiptDetail::insert($data3);

                            DB::table('ledgers')->where('receipt_id',$id)->delete();
                            Profit::where('receipt_id',$id)->delete();

                            $data4 = [
                                'amount' => -($request->payment_amount),
                                'receipt_id' => $receipt_id,
                                'type' => 'Expense',
                            ];
                             Profit::insert($data4);


                        }

                    // $user = User::create($user_data);
                DB::commit();
                return redirect()->route('receipt.index')->with('success', 'Updated Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();

            return back()->with('error', 'Data Not Inserted Please Try Again! ' . '' . $e->getLine() . ' - ' . $e->getMessage());
        }

        // return redirect()->route('payment.index')->with('success', 'Updated Successfully!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // dd($id);
        $fdelete = Restuarant::find($id);
        $fdelete->delete();
        return redirect()->route('payment.index');
    }


    public function validateRestuarant(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|max:100|string',
            'email' => 'required|email|unique:restaurants,restaurant_email',
            // 'restaurants_phone_unique' => 'required|unique'
        ]);
    }

    public function feature_restaurent()
    {
        $data['restuarants'] = Restuarant::all();
        return view('backend.pages.payment.featured', $data);
    }

    public function make_feature_restaurent(Request $request)
    {
        $rest_id = $request->id;

        $check = DB::table('feature_restaurants')->where('restaurants_id', $rest_id)->first();
        if ($check) {
            DB::table('feature_restaurants')->where('restaurants_id', $rest_id)->delete();
            return response()->json(['status' => 'deleted']);
        }
        // if not exist then insert it
        $data = [
            'restaurants_id' => $rest_id,
            'is_feature' => 1
        ];
        DB::table('feature_restaurants')->insert($data);
        return response()->json(['status' => 'inserted']);
    }
}
