<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\RestaurantTiming;
use Illuminate\Http\Request;

class RestaurantTimingsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $restaurant_id = auth()->user()->restaurant_id;
        $timings = RestaurantTiming::where('restaurant_id', $restaurant_id)->get();
        // sort the timings by day from monday to sunday
        $timings = $timings->sortBy(function($timings) {
            return $timings->day;
        });

        return view('backend.restaurant-panel.timings.index',compact('timings'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $restaurant_id = auth()->user()->restaurant_id;

        return view('backend.restaurant-panel.timings.create', compact('restaurant_id'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'day' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
        ]);

        unset($request['_token']);

        $restaurant_id = $request->restaurant_id;
        $day = $request->day;
        $restaurant_timing = RestaurantTiming::where('restaurant_id', $restaurant_id)->where('day', $day)->first();
        if($restaurant_timing){
            $restaurant_timing->update($request->all());
            return redirect()->route('timings.index')
            ->with('success','Restaurant Timing updated successfully.');
        }
        RestaurantTiming::create($request->all());

        return redirect()->route('timings.index')
            ->with('success','Restaurant Timing created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $timing = RestaurantTiming::find($id);
        return view('backend.restaurant-panel.timings.edit',compact('timing'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'day' => 'required',
            'opening_time' => 'required',
            'closing_time' => 'required',
        ]);

        $timing = RestaurantTiming::find($id);
        $timing->update($request->all());

        return redirect()->route('timings.index')
            ->with('success','Restaurant Timing updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $timing = RestaurantTiming::findOrFail($id);

        $timing->delete();

        return redirect()->route('timings.index')
            ->with('success','Restaurant Timing deleted successfully');
    }
}
