<?php

namespace App\Http\Controllers\backend;

use App\Http\Controllers\Controller;
use App\Models\backend\Restuarant;
use App\Models\backend\Zone;
use App\Models\backend\Food;
use App\Models\User;
use Facade\FlareClient\Http\Response;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class RestuarantController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $data['restuarants'] = Restuarant::orderBy('id', 'Desc')->get();
        return view('backend.pages.restuarant.index', $data);
    }



    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $zones = Zone::where('status',1)->get();
        return view('backend.pages.restuarant.create', compact('zones'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request->all());

        $request->validate([
            'name' => 'required',
            'restaurant_name' => 'required',
            'restaurant_email' => 'required|email|unique:restaurants,restaurant_email',
            'phone' => 'required|unique:restaurants,phone',
            'address' => 'required',
            'zone_id' => 'required',
            'status' => 'required',
            'commission' => 'required|numeric',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|confirmed|min:6',
            // 'password_confirmation' => 'required',
            'logo' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'feature_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
        $data = $request->except('_token', 'name','restaurant_name','email', 'user_type_id', 'restaurant_id', 'password', 'password_confirmation');
        $data['name']=$request->restaurant_name;

        // pr($data);
        DB::beginTransaction();
        try {

            

            if ($request->feature_image) {
                $feature_image = time() . rand(200, 400) . '.' . $request->feature_image->getClientOriginalExtension();
                $request->feature_image->move(public_path('/app/restaurant/'), $feature_image);
            } else {
                $feature_image = '';
            }
            if ($request->logo) {
                $logo = time() . rand(200, 400) . '.' . $request->logo->getClientOriginalExtension();
                $request->logo->move(public_path('/app/restaurant/'), $logo);
            } else {
                $logo = '';
            }
            $data['logo'] = $logo;
            $data['feature_image'] = $feature_image;
            $res_id = Restuarant::insertGetId($data);

            $passwords = $request->password;
            $user_data = [
                'name' => $request->name,
                'user_type_id' => 2,
                'restaurant_id' => $res_id,
                'email' => $request->email,
                'password' => Hash::make($passwords)
            ];

            $user = User::create($user_data);
            DB::commit();
            return redirect()->route('restuarants.index')->with('success', 'Added Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();

            return back()->with('error', 'Data Not Inserted Please Try Again!' . '' . $e->getLine() . ' - ' . $e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //  dd($id);
        $rest=Restuarant::with('user')->find($id);
        // dd($rest);
        $items=Food::where('restaurant_id',$id)->get();

       $users = User::where('restaurant_id',$id)->get();
        // dd($users);
            $pendingCount = DB::table('orders')
            ->where('order_status', 'pending')->where('restaurant_id',$id)
            ->count();

            $acceptedCount = DB::table('orders')
            ->where('order_status', 'accepted')->where('restaurant_id',$id)
            ->count();

            $rejectedCount = DB::table('orders')
            ->where('order_status', 'rejected')->where('restaurant_id',$id)
            ->count();
            $total_amount = DB::table('orders')
            ->where('restaurant_id', $id) // Replace $id with the desired restaurant ID
            ->sum('order_amount');
        return view('backend.pages.restuarant.single_restaurant_view', compact('rest','items','pendingCount','acceptedCount','rejectedCount','total_amount','users') );
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $data['restuarant'] = Restuarant::findOrFail($id);
        $data['zones'] = Zone::all();

        return view('backend.pages.restuarant.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $model = Restuarant::findOrFail($id);
        $request->validate([
            'name' => 'required',
            'zone_id' => 'required',
            'status' => 'required',
            'restaurant_email' => 'required|email|unique:restaurants,restaurant_email,' . $id,
            'phone' => 'required|unique:restaurants,phone,' . $id,
            'address' => 'required',
            'commission' => 'required|numeric',
            // 'logo' => 'mimes:jpeg,png,jpg,gif,svg|max:2048',
            // 'feature_image' => 'image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);
        $data = $request->except('_token', 'email', 'user_type_id', 'restaurant_id', 'password', 'password_confirmation', '_method');
        // $data['user_id'] = Auth::user()->id;
        if ($request->feature_image) {
            $feature_image = time() . rand(200, 400) . '.' . $request->feature_image->getClientOriginalExtension();
            $request->feature_image->move(public_path('/app/restaurant/'), $feature_image);
        } else {
            $feature_image = '';
        }

        if ($request->logo) {
                $logo = time() . rand(200, 400) . '.' . $request->logo->getClientOriginalExtension();
                $request->logo->move(public_path('/app/restaurant/'), $logo);
            } else {
                $logo = '';
            }
        $data['logo'] = $logo;
        $data['feature_image'] = $feature_image;
        $model->update($data);

        return redirect()->route('restuarants.index')->with('success', 'Updated Successfully!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // dd($id);
        $fdelete = Restuarant::find($id);
        $fdelete->delete();
        return redirect()->route('restuarants.index');
    }


    public function validateRestuarant(Request $request)
    {
        $this->validate($request, [
            'name' => 'required|max:100|string',
            'email' => 'required|email|unique:restaurants,restaurant_email',
            // 'restaurants_phone_unique' => 'required|unique'
        ]);
    }

    public function feature_restaurent()
    {
        $data['restuarants'] = Restuarant::all();
        return view('backend.pages.restuarant.featured', $data);
    }

    public function make_feature_restaurent(Request $request)
    {
        $rest_id = $request->id;

        $check = DB::table('feature_restaurants')->where('restaurants_id', $rest_id)->first();
        if ($check) {
            DB::table('feature_restaurants')->where('restaurants_id', $rest_id)->delete();
            return response()->json(['status' => 'deleted']);
        }
        // if not exist then insert it
        $data = [
            'restaurants_id' => $rest_id,
            'is_feature' => 1
        ];
        DB::table('feature_restaurants')->insert($data);
        return response()->json(['status' => 'inserted']);
    }
}
